#ifndef NT2_INCLUDE_CONSTANTS_MTWO_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MTWO_HPP_INCLUDED

#include <nt2/constant/include/constants/mtwo.hpp>

#endif
